==> kcalutils-24.01.80-1-x86_64.pkg.tar.zst: usr/lib/cmake/KPim6CalendarUtils/KPim6CalendarUtilsConfig.cmake <==
# SPDX-FileCopyrightText: none
# SPDX-License-Identifier: BSD-3-Clause

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KPimCalendarUtilsConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KPim6CalendarUtils" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)
find_dependency(KF6CoreAddons "5.245.0")
find_dependency(KF6Config "5.245.0")
find_dependency(KF6CalendarCore "5.245.0")

include("${CMAKE_CURRENT_LIST_DIR}/KPim6CalendarUtilsTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/KPim6CalendarUtilsQchTargets.cmake")

==> kcalutils-24.02.2-1-x86_64.pkg.tar.zst: usr/lib/cmake/KPim6CalendarUtils/KPim6CalendarUtilsConfig.cmake <==
# SPDX-FileCopyrightText: none
# SPDX-License-Identifier: BSD-3-Clause

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KPimCalendarUtilsConfig.cmake.in                            ########

get_filename_component(PACKAGE_${CMAKE_FIND_PACKAGE_NAME}_COUNTER_1 "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KPim6CalendarUtils" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_${CMAKE_FIND_PACKAGE_NAME}_COUNTER_1 "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)
find_dependency(KF6CoreAddons "5.246.0")
find_dependency(KF6Config "5.246.0")
find_dependency(KF6CalendarCore "5.246.0")

include("${CMAKE_CURRENT_LIST_DIR}/KPim6CalendarUtilsTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/KPim6CalendarUtilsQchTargets.cmake")
